@@ -1,10 +1,10 @@
 use std::ops::Deref;
 
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
 
 use crate::{CompTag, BYTE_ARRAY_TAG, INT_ARRAY_TAG, LONG_ARRAY_TAG};
 
-#[derive(Deserialize, Debug, Clone, PartialEq)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq)]
 pub struct ByteArray {
     tag: CompTag<BYTE_ARRAY_TAG>,
     data: Vec<i8>,
@@ -18,7 +18,7 @@ impl Deref for ByteArray {
     }
 }
 
-#[derive(Deserialize, Debug, Clone, PartialEq)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq)]
 pub struct IntArray {
     tag: CompTag<INT_ARRAY_TAG>,
     data: Vec<i32>,
@@ -32,7 +32,7 @@ impl Deref for IntArray {
     }
 }
 
-#[derive(Deserialize, Debug, Clone, PartialEq)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq)]
 pub struct LongArray {
     tag: CompTag<LONG_ARRAY_TAG>,
     data: Vec<i64>,
